==> PPDF_1_3.zip: PubMedPDF/search.php <==
<?php
	include "header.php";
	include "include/pubmed.php";
	include "include/db.php";
	include "include/Get_Journal.php";
	include "style.php";

	$search_xml = "search_xml/";
	if(!is_dir($search_xml)) $rc = mkdir($search_xml, 0777);
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
	
	## Proxy
        include (XOOPS_ROOT_PATH."/class/snoopy.php");
	if($xoopsModuleConfig['proxy']){
//		include (XOOPS_ROOT_PATH."/class/snoopy.php");
		$proxy = new Snoopy;
		$proxy->read_timeout = 0;
		$proxy->proxy_host = $xoopsModuleConfig['proxy_url'];
		$proxy->proxy_port = $xoopsModuleConfig['proxy_port'];
	}else{
		$proxy = 0;
		$snoopy = new Snoopy;
	}

	##---------------------------------------------------

	# search form
	if(@$_POST["keywords"]){
		$keywords = @$_POST["keywords"];
		$retmax = @$_POST["retmax"];
	}elseif(@$_GET["key"]){
		$keywords = @$_GET["key"];
		$retmax = @$_GET["ret"];
	}else{
		$retmax = 5;
	}

	$title = _MD_PubMedSearch;
	echo <<<E
	<form enctype="multipart/form-data" action="$_SERVER[PHP_SELF]" method="POST">
	<div class="pt">$title</div>
	<div class="pc">
		<table>
			<tr>
				<td style="width:80px"><b>keywords</b></td>
				<td><input type="text" style="width:60%" name="keywords" value="$keywords"></td>
			</tr>
			<tr>
				<td><b>Number</b></td>
				<td>
E;
					$ret_array = array(5,10,20,50,100,200);
					for($i=0; $i<count($ret_array); $i++){
						echo "<input type=\"radio\" name=\"retmax\" value=\"".$ret_array[$i]."\"";
						if($retmax == $ret_array[$i]) echo " checked";
						echo ">".$ret_array[$i]." ";

					}						
	
				echo <<<E
				</td>
			</tr>
			<tr>
				<td><b>Display</b></td>
				<td>
E;
					if($dispSW){
						echo "<input type=\"radio\" name=\"dispSW\" value=\"0\">All";
						echo "<input type=\"radio\" name=\"dispSW\" value=\"1\" checked>Selected";
					}else{
						echo "<input type=\"radio\" name=\"dispSW\" value=\"0\" checked>All";
						echo "<input type=\"radio\" name=\"dispSW\" value=\"1\">Selected";
					}
					
				echo <<<E
				</td>
			</tr>
			<tr>
				<td><b>Search</b></td>
				<td>
					<input type="submit" name="search" value="Go">
				</td>
			</tr>
		</table>
	</div>
	</form>
E;

	##---------------------------------------------------

	## deal with checked items
	if(@$_POST["check_submit"]){

		## uninterest pmid
		if(@$_POST["check_method"] == "uninterest_submit"){
		
			foreach(@$_POST["uninterest"] as $pmid){
				$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='uninterest' AND tmp2='".$user."' AND tmp3='".$pmid."'";
				$res = mysql_query($sql, $conn);
				if(mysql_num_rows($res) > 0){
					$sql = "DELETE FROM ".$T_TMP." WHERE tmp1='uninterest' AND tmp2='".$user."' AND tmp3='".$pmid."'";
					$res = mysql_query($sql, $conn);
				}else{
					$sql = "INSERT INTO ".$T_TMP." VALUES('uninterest','".$user."','".$pmid."','')";
					$res = mysql_query($sql, $conn);
				}
			}	
		}
		
		##register
		if(@$_POST["check_method"] == "register"){
			echo "<hr>";

			foreach(@$_POST["uninterest"] as $pmid){
				
				$count = 0;
				echo "<b>[".$pmid."]</b> ";	
				$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$pmid."'";
				$res = mysql_query($sql, $conn);
				if(mysql_num_rows($res) != 0){
					echo "already registered.<br>";
				}else{
					if($count > 70){
						for($j=0;$j<10000;$j++);
						$count = 0;
					}
					
					if(file_exists("pubmed_xml/$pmid.xml")){
						$pm_data = PubMedByFile( $pmid, 'pubmed_xml/', 0 );
 						echo substr($pm_data[t], 0, 80)."..<br>";
						DB($pm_data, $user);
						
					}elseif(file_exists("search_xml/$pmid.xml")){
						$pm_data = PubMedByFile( $pmid, 'search_xml/', 0 );
						echo substr($pm_data[t], 0, 80)."..<br>";
						DB($pm_data, $user);
						rename( "search_xml/$pmid.xml", "pubmed_xml/$pmid.xml" );
						
					}else{
						if(!$pm_data = PubMed($pmid, $proxy, $snoopy, 'pubmed_xml/')){
							echo "id missing...<br>";
						}else{
							echo substr($pm_data[t], 0, 80)."..<br>";
							DB($pm_data, $user);
						}
					}
				}
				$count ++;
			}
		}
	}
	
	##---------------------------------------------------
	
	## search result
	if(@$_POST["search"] || @$_GET["p"]){

		if(@$_POST["search"]){
			$keywords = str_replace(" ","+", @$_POST["keywords"]);
			$retmax = @$_POST["retmax"];
			$sw = @$_POST["dispSW"];
			$page = 1;

		}elseif(@$_GET["p"]){
			$keywords = str_replace(" ","+", @$_GET["key"]);
			$retmax = @$_GET["ret"];
			$sw = @$_GET["sw"];
			$page = @$_GET["p"];
			$allpage = @$_GET["all"];
		}
		$startNo = ($page - 1) * $retmax;
		
				
		## PubMed Search & Fetch
		$pm_data = PubMedKWSearch($keywords,$proxy,$snoopy,$retmax,$startNo);
		if($pm_data[n] == 0){
			echo "Search condition: No items found.<br>";

		}else{
		
			# paging
			$num = $pm_data[n];
			$allpage = ceil($pm_data[n] / $retmax);
			$prepage = $page - 1;
			if($prepage < 1){
				$prepage = 1;
			}
			$nextpage = $page + 1;
			$keywords = str_replace("+"," ", $keywords);

			echo "<form action=\"$_SERVER[PHP_SELF]\" method=\"GET\" style=\"margin:0\">";
			echo "<hr><b>Total:</b> $pm_data[n] &nbsp;&nbsp;&nbsp;&nbsp;";
			if($page > 1){
				echo "<a href=\"".$SERVER[PHP_SELF]."?p=".$prepage."&all=".$allpage."&key=".$keywords."&ret=".$retmax."&sw=".$sw."\">";
				echo "<img src=\"images/left.png\"></a> ";
			}
			echo $page." / ".$allpage;
			if(($nextpage -1) * $retmax < $num){
				echo "<a href=\"".$SERVER[PHP_SELF]."?p=".$nextpage."&all=".$allpage."&key=".$keywords."&ret=".$retmax."&sw=".$sw."\">";
				echo " <img src=\"images/right.png\"></a>";
			}
			
			echo "&nbsp;&nbsp;&nbsp;&nbsp;<b>Move to the page</b>";
			echo " <select name=\"p\">";
			for($i=1; $i<=$allpage; $i++){
				echo "<option value=\"".$i."\">".$i."</option>";
			}
			echo "</select> ";
			echo <<<E
			<input type="submit" value="Go">
			<input type="hidden" value="$keywords" name="key">
			<input type="hidden" value="$retmax" name="ret">
			<input type="hidden" value="$sw" name="sw">
			<input type="hidden" value="$allpage" name="all">
E;
			echo "<hr><br></form>";

			# show data
			echo "<form action=\"$_SERVER[PHP_SELF]\" method=\"POST\">";
			$pmids = explode( ",", $pm_data[p] );
			foreach ( $pmids as $pmid ) {
				$unint = 0;
				$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$pmid."'";
				$res = mysql_query($sql, $conn);
				
				# registered bibliography
				if(mysql_num_rows($res) != 0){
					if (!$sw) {

						if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
						$item = array("id"=>$row["PMID"], "a"=>$row["Author"],
													"t"=>$row["Title"], "v"=>$row["Volume"], 
													"p"=>$row["Page"], "y"=>$row["Year"], 
													"ab"=>$row["Abstract"], "j"=>$row["Journal"],
													"t_jp"=>$row["Title_JP"], 
													"a_jp"=>$row["Author_JP"]
												);

						# get authors from database
						$author="";
						$a = explode(",",substr($item[a],0,-1));
						for($k=0; $k<count($a); $k++){
							$a[$k] = str_replace("[","",$a[$k]);
							$a[$k] = str_replace("]","",$a[$k]);
							$sql2 = "SELECT Author FROM ".$T_AUTHOR." WHERE id='".$a[$k]."'";
							$res2 = mysql_query($sql2, $conn);
							$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);
							$author.=$row2["Author"].", ";
						}
						$author = substr($author,0,-2);
						
						# get journal
						$sql2 = "SELECT * FROM ".$T_JOURNAL." WHERE id='".$item[j]."'";
						$res2 = mysql_query($sql2, $conn);
						$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);
						$journal = $row2["Journal"];
							
						
						#abst
						if($item[ab]){
							$abst = "[<a href=\"javascript:disp('include/show_abst.php?abst=".$item[id]."',500,300)\">Abstract</a>]";
						}else{
							$abst = "";
						}

						$up_dir = $xoopsModuleConfig['updir2'];
						if(substr($up_dir,-1) != "/") $up_dir.="/";

						if(file_exists($up_dir.$pmid.".pdf")){
							$link2pdf = "<a  target=\"_blank\" href=\"http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=search&term=".$pmid."\">$pmid</a>";
							$link3pdf = "[<a target=\"_blank\" href=\"$up_dir$pmid.pdf\">PDF</a>]";
							$class = "head";
							$color = "black";

						}else{
							$link2pdf = "<a  target=\"_blank\" href=\"http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=search&term=".$pmid."\">$pmid</a>";
							$link3pdf = "";
							$class = "even";
							$color = "black";
						}

						echo <<<E
						<table class="outer" style="width:100%">
						<tr>
							<td rowspan="3" class="head" style="width:20px"></td>
							<td colspan="2" class="$class" align="left"><font color="$color">$item[t]</font></td>
						</tr>
						<tr>
							<td colspan="2" class="even">$author</td>
						</tr>
						<tr>
							<td>PMID[$link2pdf]</td>
							<td style="text-align:right">$journal $abst $link3pdf</td>
						</tr>
						</table><br>
E;
					}
				# non registered bibliography
				}else{
					
					if(file_exists($search_xml.$pmid.'.xml')){
						$pm_data = PubMedByFile( $pmid, $search_xml, 1 );

					}else{
						$pm_data = PubMed( $pmid, $proxy, $snoopy, $search_xml, 1 );
					}

					$id = "<a target=\"_blank\" href=\"http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=search&term=".$pmid."\">".$pmid."</a>";
					$check = "<input type=\"checkbox\" name=\"uninterest[]\" "."value=\"$pmid\">";

					/*
					$k = explode(" ", $keywords);
					for($i=0; $i<count($k); $i++){
						$pm_data[a] = eregi_replace($k[$i], "<b>".$k[$i]."</b>", $pm_data[a]);
					}
					*/

					#abst
					if($pm_data[ab]){
						$abst = str_replace("'","\'",$pm_data[ab]);
						$abst = str_replace("\"","\\\\",$abst);
						$abst = "[<a href=\"javascript:disp('include/show_abst.php?abst2=".$abst."',500,300)\">Abstract</a>]";
					}else{
						$abst = "";
					}
			
					$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='uninterest' AND tmp2='".$user."' AND tmp3='".$pmid."'";
					$res = mysql_query($sql, $conn);
					if(mysql_num_rows($res) > 0){
						# all
						if(!$sw){
							echo <<<E
							<table class="outer" style="width:100%">
							<tr>
								<td rowspan="3" class="head" style="width:20px">$check</td>
								<td colspan="2" class="even" align="left"><font color="blue">$pm_data[t]</font></td>
							</tr>
							<tr>
								<td colspan="2" class="even">$pm_data[a]</td>
							</tr>
							<tr>
								<td>PMID[$id]</td>
								<td style="text-align:right">$pm_data[j] $abst</td>
							</tr>
							</table><br>
E;
						}
					# selected
					}else{
						echo <<<E
						<table class="outer" style="width:100%">
						<tr>
							<td rowspan="3" class="head" style="width:20px">$check</td>
							<td colspan="2" class="even" align="left"><font color="red">$pm_data[t]</font></td>
						</tr>
						<tr>
							<td colspan="2" class="even">$pm_data[a]</td>
						</tr>
						<tr>
							<td>PMID[$id]</td>
							<td style="text-align:right">$pm_data[j] $abst</td>
						</tr>
						</table><br>
E;
					}
				}
			}

			echo "<hr><br>";
			$i = _MD_PubMedSearch_unin_submit;
			$j = _MD_PubMedSearch_regist_submit;
			echo <<<E
			<input type="radio" name="check_method" value="uninterest_submit" checked> $i<br>
			<input type="radio" name="check_method" value="register"> $j<br><br>
			<input type="submit" value="submit" name="check_submit">
			<input type="hidden" value="$keywords" name="keywords">
			<input type="hidden" value="$retmax" name="retmax">
			<input type="hidden" value="$sw" name="dispSW">
			<input type="hidden" value="y" name="search">
			</form>
E;
		}
	}
	
	include (XOOPS_ROOT_PATH."/footer.php");
?>

==> PPDF_1_4.zip: PubMedPDF/search.php <==
<?php
	include "header.php";
	include "include/pubmed.php";
	include "include/db.php";
	include "include/Get_Journal.php";
	include "style.php";

	$search_xml = "search_xml/";
	if(!is_dir($search_xml)) $rc = mkdir($search_xml, 0777);
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
	
	## Proxy
        include (XOOPS_ROOT_PATH."/class/snoopy.php");
	if($xoopsModuleConfig['proxy']){
//		include (XOOPS_ROOT_PATH."/class/snoopy.php");
		$proxy = new Snoopy;
		$proxy->read_timeout = 0;
		$proxy->proxy_host = $xoopsModuleConfig['proxy_url'];
		$proxy->proxy_port = $xoopsModuleConfig['proxy_port'];
	}else{
		$proxy = 0;
		$snoopy = new Snoopy;
	}

	##---------------------------------------------------

	# search form
	if(@$_POST["keywords"]){
		$keywords = @$_POST["keywords"];
		$retmax = @$_POST["retmax"];
	}elseif(@$_GET["key"]){
		$keywords = @$_GET["key"];
		$retmax = @$_GET["ret"];
	}else{
		$retmax = 5;
	}

	$title = _MD_PubMedSearch;
	echo <<<E
	<form enctype="multipart/form-data" action="$_SERVER[PHP_SELF]" method="POST">
	<div class="pt">$title</div>
	<div class="pc">
		<table>
			<tr>
				<td style="width:80px"><b>keywords</b></td>
				<td><input type="text" style="width:60%" name="keywords" value="$keywords"></td>
			</tr>
			<tr>
				<td><b>Number</b></td>
				<td>
E;
					$ret_array = array(5,10,20,50,100,200);
					for($i=0; $i<count($ret_array); $i++){
						echo "<input type=\"radio\" name=\"retmax\" value=\"".$ret_array[$i]."\"";
						if($retmax == $ret_array[$i]) echo " checked";
						echo ">".$ret_array[$i]." ";

					}						
	
				echo <<<E
				</td>
			</tr>
			<tr>
				<td><b>Display</b></td>
				<td>
E;
					if($dispSW){
						echo "<input type=\"radio\" name=\"dispSW\" value=\"0\">All";
						echo "<input type=\"radio\" name=\"dispSW\" value=\"1\" checked>Selected";
					}else{
						echo "<input type=\"radio\" name=\"dispSW\" value=\"0\" checked>All";
						echo "<input type=\"radio\" name=\"dispSW\" value=\"1\">Selected";
					}
					
				echo <<<E
				</td>
			</tr>
			<tr>
				<td><b>Search</b></td>
				<td>
					<input type="submit" name="search" value="Go">
				</td>
			</tr>
		</table>
	</div>
	</form>
E;

	##---------------------------------------------------

	## deal with checked items
	if(@$_POST["check_submit"]){

		## uninterest pmid
		if(@$_POST["check_method"] == "uninterest_submit"){
		
			foreach(@$_POST["uninterest"] as $pmid){
				$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='uninterest' AND tmp2='".$user."' AND tmp3='".$pmid."'";
				$res = mysql_query($sql, $conn);
				if(mysql_num_rows($res) > 0){
					$sql = "DELETE FROM ".$T_TMP." WHERE tmp1='uninterest' AND tmp2='".$user."' AND tmp3='".$pmid."'";
					$res = mysql_query($sql, $conn);
				}else{
					$sql = "INSERT INTO ".$T_TMP." VALUES('uninterest','".$user."','".$pmid."','')";
					$res = mysql_query($sql, $conn);
				}
			}	
		}
		
		##register
		if(@$_POST["check_method"] == "register"){
			echo "<hr>";

			foreach(@$_POST["uninterest"] as $pmid){
				
				$count = 0;
				echo "<b>[".$pmid."]</b> ";	
				$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$pmid."'";
				$res = mysql_query($sql, $conn);
				if(mysql_num_rows($res) != 0){
					echo "already registered.<br>";
				}else{
					if($count > 70){
						for($j=0;$j<10000;$j++);
						$count = 0;
					}
					
					if(file_exists("pubmed_xml/$pmid.xml")){
						$pm_data = PubMedByFile( $pmid, 'pubmed_xml/', 0 );
 						echo substr($pm_data[t], 0, 80)."..<br>";
						DB($pm_data, $user);
						
					}elseif(file_exists("search_xml/$pmid.xml")){
						$pm_data = PubMedByFile( $pmid, 'search_xml/', 0 );
						echo substr($pm_data[t], 0, 80)."..<br>";
						DB($pm_data, $user);
						rename( "search_xml/$pmid.xml", "pubmed_xml/$pmid.xml" );
						
					}else{
						if(!$pm_data = PubMed($pmid, $proxy, $snoopy, 'pubmed_xml/')){
							echo "id missing...<br>";
						}else{
							echo substr($pm_data[t], 0, 80)."..<br>";
							DB($pm_data, $user);
						}
					}
				}
				$count ++;
			}
		}
	}
	
	##---------------------------------------------------
	
	## search result
	if(@$_POST["search"] || @$_GET["p"]){

		if(@$_POST["search"]){
			$keywords = str_replace(" ","+", @$_POST["keywords"]);
			$retmax = @$_POST["retmax"];
			$sw = @$_POST["dispSW"];
			$page = @$_POST["page"];
			if ( $page <= 1) $page = 1;

		}elseif(@$_GET["p"]){
			$keywords = str_replace(" ","+", @$_GET["key"]);
			$retmax = @$_GET["ret"];
			$sw = @$_GET["sw"];
			$page = @$_GET["p"];
			$allpage = @$_GET["all"];
		}
		$startNo = ($page - 1) * $retmax;
		
				
		## PubMed Search & Fetch
		$pm_data = PubMedKWSearch($keywords,$proxy,$snoopy,$retmax,$startNo);
		if($pm_data[n] == 0){
			echo "Search condition: No items found.<br>";

		}else{
		
			# paging
			$num = $pm_data[n];
			$allpage = ceil($pm_data[n] / $retmax);
			$prepage = $page - 1;
			if($prepage < 1){
				$prepage = 1;
			}
			$nextpage = $page + 1;
			$keywords = str_replace("+"," ", $keywords);

			echo "<form action=\"$_SERVER[PHP_SELF]\" method=\"GET\" style=\"margin:0\">";
			echo "<hr><b>Total:</b> $pm_data[n] &nbsp;&nbsp;&nbsp;&nbsp;";
			if($page > 1){
				echo "<a href=\"".$SERVER[PHP_SELF]."?p=".$prepage."&all=".$allpage."&key=".$keywords."&ret=".$retmax."&sw=".$sw."\">";
				echo "<img src=\"images/left.png\"></a> ";
			}
			echo $page." / ".$allpage;
			if(($nextpage -1) * $retmax < $num){
				echo "<a href=\"".$SERVER[PHP_SELF]."?p=".$nextpage."&all=".$allpage."&key=".$keywords."&ret=".$retmax."&sw=".$sw."\">";
				echo " <img src=\"images/right.png\"></a>";
			}
			
			echo "&nbsp;&nbsp;&nbsp;&nbsp;<b>Move to the page</b>";
			echo " <select name=\"p\">";
			for($i=1; $i<=$allpage; $i++){
				echo "<option value=\"".$i."\">".$i."</option>";
			}
			echo "</select> ";
			echo <<<E
			<input type="submit" value="Go">
			<input type="hidden" value="$keywords" name="key">
			<input type="hidden" value="$retmax" name="ret">
			<input type="hidden" value="$sw" name="sw">
			<input type="hidden" value="$allpage" name="all">
E;
			echo "<hr><br></form>";

			# show data
			echo "<form action=\"$_SERVER[PHP_SELF]\" method=\"POST\">";
			$pmids = explode( ",", $pm_data[p] );
			foreach ( $pmids as $pmid ) {
				$unint = 0;
				$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$pmid."'";
				$res = mysql_query($sql, $conn);
				
				# registered bibliography
				if(mysql_num_rows($res) != 0){
					if (!$sw) {

						if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
						$item = array("id"=>$row["PMID"], "a"=>$row["Author"],
													"t"=>$row["Title"], "v"=>$row["Volume"], 
													"p"=>$row["Page"], "y"=>$row["Year"], 
													"ab"=>$row["Abstract"], "j"=>$row["Journal"],
													"t_jp"=>$row["Title_JP"], 
													"a_jp"=>$row["Author_JP"]
												);

						# get authors from database
						$author="";
						$a = explode(",",substr($item[a],0,-1));
						for($k=0; $k<count($a); $k++){
							$a[$k] = str_replace("[","",$a[$k]);
							$a[$k] = str_replace("]","",$a[$k]);
							$sql2 = "SELECT Author FROM ".$T_AUTHOR." WHERE id='".$a[$k]."'";
							$res2 = mysql_query($sql2, $conn);
							$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);
							$author.=$row2["Author"].", ";
						}
						$author = substr($author,0,-2);
						
						# get journal
						$sql2 = "SELECT * FROM ".$T_JOURNAL." WHERE id='".$item[j]."'";
						$res2 = mysql_query($sql2, $conn);
						$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);
						$journal = $row2["Journal"];
							
						
						#abst
						if($item[ab]){
							$abst = "[<a href=\"javascript:disp('include/show_abst.php?abst=".$item[id]."',500,300)\">Abstract</a>]";
						}else{
							$abst = "";
						}

						$up_dir = $xoopsModuleConfig['updir2'];
						if(substr($up_dir,-1) != "/") $up_dir.="/";

						if(file_exists($up_dir.$pmid.".pdf")){
							$link2pdf = "<a  target=\"_blank\" href=\"http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=search&term=".$pmid."\">$pmid</a>";
							$link3pdf = "[<a target=\"_blank\" href=\"$up_dir$pmid.pdf\">PDF</a>]";
							$class = "head";
							$color = "black";

						}else{
							$link2pdf = "<a  target=\"_blank\" href=\"http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=search&term=".$pmid."\">$pmid</a>";
							$link3pdf = "[<a href=\"javascript:disp('pdf_add.php?id=".$pmid."',300,120)\">upload</a>]";
							$class = "even";
							$color = "black";
						}

						echo <<<E
						<table class="outer" style="width:100%">
						<tr>
							<td rowspan="3" class="head" style="width:20px"></td>
							<td colspan="2" class="$class" align="left"><font color="$color">$item[t]</font></td>
						</tr>
						<tr>
							<td colspan="2" class="even">$author</td>
						</tr>
						<tr>
							<td>PMID[$link2pdf]</td>
							<td style="text-align:right">$journal-$item[y] $abst $link3pdf</td>
						</tr>
						</table><br>
E;
					}
				# non registered bibliography
				}else{
					
					if(file_exists($search_xml.$pmid.'.xml')){
						$pm_data = PubMedByFile( $pmid, $search_xml, 1 );

					}else{
						$pm_data = PubMed( $pmid, $proxy, $snoopy, $search_xml, 1 );
					}

					$id = "<a target=\"_blank\" href=\"http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=search&term=".$pmid."\">".$pmid."</a>";
					$check = "<input type=\"checkbox\" name=\"uninterest[]\" "."value=\"$pmid\">";

					/*
					$k = explode(" ", $keywords);
					for($i=0; $i<count($k); $i++){
						$pm_data[a] = eregi_replace($k[$i], "<b>".$k[$i]."</b>", $pm_data[a]);
					}
					*/

					#abst
					if($pm_data[ab]){
						$abst = str_replace("'","\'",$pm_data[ab]);
						$abst = str_replace("\"","\\\\",$abst);
						$abst = "[<a href=\"javascript:disp('include/show_abst.php?abst2=".$abst."',500,300)\">Abstract</a>]";
					}else{
						$abst = "";
					}
			
					$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='uninterest' AND tmp2='".$user."' AND tmp3='".$pmid."'";
					$res = mysql_query($sql, $conn);
					if(mysql_num_rows($res) > 0){
						# all
						if(!$sw){
							echo <<<E
							<table class="outer" style="width:100%">
							<tr>
								<td rowspan="3" class="head" style="width:20px">$check</td>
								<td colspan="2" class="even" align="left"><font color="blue">$pm_data[t]</font></td>
							</tr>
							<tr>
								<td colspan="2" class="even">$pm_data[a]</td>
							</tr>
							<tr>
								<td>PMID[$id]</td>
								<td style="text-align:right">$pm_data[j]-$pm_data[y] $abst</td>
							</tr>
							</table><br>
E;
						}
					# selected
					}else{
						echo <<<E
						<table class="outer" style="width:100%">
						<tr>
							<td rowspan="3" class="head" style="width:20px">$check</td>
							<td colspan="2" class="even" align="left"><font color="red">$pm_data[t]</font></td>
						</tr>
						<tr>
							<td colspan="2" class="even">$pm_data[a]</td>
						</tr>
						<tr>
							<td>PMID[$id]</td>
							<td style="text-align:right">$pm_data[j]-$pm_data[y] $abst</td>
						</tr>
						</table><br>
E;
					}
				}
			}

			echo "<hr><br>";
			$i = _MD_PubMedSearch_unin_submit;
			$j = _MD_PubMedSearch_regist_submit;
			echo <<<E
			<input type="radio" name="check_method" value="uninterest_submit" checked> $i<br>
			<input type="radio" name="check_method" value="register"> $j<br><br>
			<input type="submit" value="submit" name="check_submit">
			<input type="hidden" value="$keywords" name="keywords">
			<input type="hidden" value="$retmax" name="retmax">
			<input type="hidden" value="$sw" name="dispSW">
			<input type="hidden" value="y" name="search">
			<input type="hidden" value="$page" name="page">
			</form>
E;
		}
	}
	
	include (XOOPS_ROOT_PATH."/footer.php");
?>
